@@ -1,14 +1,12 @@
 (ert-run-tests-batch-and-exit
  '(not (or
-        ;; those tests fail in autopkgtest. they should be fixed, but
-        ;; for now we feel it's better to have a partially working
-        ;; autopkgtest than the package out of stable/testing.
+        ;; Tests failing in sbuild but working on bare metal.
+        "rg-integration/rg-executable-results-buffer"
+        "rg-integration/rg-executable-through-rg-run"
+        ;; Tests failing in autopkgtest due to not a git repository anymore.
         "rg-integration-test/project-root"
         "rg-integration/dwim-search"
         "rg-integration/project-search"
-        "rg-integration/rg-executable-results-buffer"
-        "rg-integration/rg-executable-through-rg-run"
-        "rg-integration/rg-recompile"
         "rg-unit/isearch-project"
         "rg-unit/menu-define-search"
         "rg-unit/menu-transient-insert"
